@@ -13,7 +13,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Any, Dict, List, TYPE_CHECKING, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_codedeploy.paginator import (
     ListApplicationRevisionsPaginator,
@@ -91,119 +91,119 @@ __all__ = ("CodeDeployClient",)
 
 
 class Exceptions:
-    AlarmsLimitExceededException: Boto3ClientError
-    ApplicationAlreadyExistsException: Boto3ClientError
-    ApplicationDoesNotExistException: Boto3ClientError
-    ApplicationLimitExceededException: Boto3ClientError
-    ApplicationNameRequiredException: Boto3ClientError
-    ArnNotSupportedException: Boto3ClientError
-    BatchLimitExceededException: Boto3ClientError
-    BucketNameFilterRequiredException: Boto3ClientError
-    ClientError: Boto3ClientError
-    DeploymentAlreadyCompletedException: Boto3ClientError
-    DeploymentAlreadyStartedException: Boto3ClientError
-    DeploymentConfigAlreadyExistsException: Boto3ClientError
-    DeploymentConfigDoesNotExistException: Boto3ClientError
-    DeploymentConfigInUseException: Boto3ClientError
-    DeploymentConfigLimitExceededException: Boto3ClientError
-    DeploymentConfigNameRequiredException: Boto3ClientError
-    DeploymentDoesNotExistException: Boto3ClientError
-    DeploymentGroupAlreadyExistsException: Boto3ClientError
-    DeploymentGroupDoesNotExistException: Boto3ClientError
-    DeploymentGroupLimitExceededException: Boto3ClientError
-    DeploymentGroupNameRequiredException: Boto3ClientError
-    DeploymentIdRequiredException: Boto3ClientError
-    DeploymentIsNotInReadyStateException: Boto3ClientError
-    DeploymentLimitExceededException: Boto3ClientError
-    DeploymentNotStartedException: Boto3ClientError
-    DeploymentTargetDoesNotExistException: Boto3ClientError
-    DeploymentTargetIdRequiredException: Boto3ClientError
-    DeploymentTargetListSizeExceededException: Boto3ClientError
-    DescriptionTooLongException: Boto3ClientError
-    ECSServiceMappingLimitExceededException: Boto3ClientError
-    GitHubAccountTokenDoesNotExistException: Boto3ClientError
-    GitHubAccountTokenNameRequiredException: Boto3ClientError
-    IamArnRequiredException: Boto3ClientError
-    IamSessionArnAlreadyRegisteredException: Boto3ClientError
-    IamUserArnAlreadyRegisteredException: Boto3ClientError
-    IamUserArnRequiredException: Boto3ClientError
-    InstanceDoesNotExistException: Boto3ClientError
-    InstanceIdRequiredException: Boto3ClientError
-    InstanceLimitExceededException: Boto3ClientError
-    InstanceNameAlreadyRegisteredException: Boto3ClientError
-    InstanceNameRequiredException: Boto3ClientError
-    InstanceNotRegisteredException: Boto3ClientError
-    InvalidAlarmConfigException: Boto3ClientError
-    InvalidApplicationNameException: Boto3ClientError
-    InvalidArnException: Boto3ClientError
-    InvalidAutoRollbackConfigException: Boto3ClientError
-    InvalidAutoScalingGroupException: Boto3ClientError
-    InvalidBlueGreenDeploymentConfigurationException: Boto3ClientError
-    InvalidBucketNameFilterException: Boto3ClientError
-    InvalidComputePlatformException: Boto3ClientError
-    InvalidDeployedStateFilterException: Boto3ClientError
-    InvalidDeploymentConfigIdException: Boto3ClientError
-    InvalidDeploymentConfigNameException: Boto3ClientError
-    InvalidDeploymentGroupNameException: Boto3ClientError
-    InvalidDeploymentIdException: Boto3ClientError
-    InvalidDeploymentInstanceTypeException: Boto3ClientError
-    InvalidDeploymentStatusException: Boto3ClientError
-    InvalidDeploymentStyleException: Boto3ClientError
-    InvalidDeploymentTargetIdException: Boto3ClientError
-    InvalidDeploymentWaitTypeException: Boto3ClientError
-    InvalidEC2TagCombinationException: Boto3ClientError
-    InvalidEC2TagException: Boto3ClientError
-    InvalidECSServiceException: Boto3ClientError
-    InvalidFileExistsBehaviorException: Boto3ClientError
-    InvalidGitHubAccountTokenException: Boto3ClientError
-    InvalidGitHubAccountTokenNameException: Boto3ClientError
-    InvalidIamSessionArnException: Boto3ClientError
-    InvalidIamUserArnException: Boto3ClientError
-    InvalidIgnoreApplicationStopFailuresValueException: Boto3ClientError
-    InvalidInputException: Boto3ClientError
-    InvalidInstanceIdException: Boto3ClientError
-    InvalidInstanceNameException: Boto3ClientError
-    InvalidInstanceStatusException: Boto3ClientError
-    InvalidInstanceTypeException: Boto3ClientError
-    InvalidKeyPrefixFilterException: Boto3ClientError
-    InvalidLifecycleEventHookExecutionIdException: Boto3ClientError
-    InvalidLifecycleEventHookExecutionStatusException: Boto3ClientError
-    InvalidLoadBalancerInfoException: Boto3ClientError
-    InvalidMinimumHealthyHostValueException: Boto3ClientError
-    InvalidNextTokenException: Boto3ClientError
-    InvalidOnPremisesTagCombinationException: Boto3ClientError
-    InvalidOperationException: Boto3ClientError
-    InvalidRegistrationStatusException: Boto3ClientError
-    InvalidRevisionException: Boto3ClientError
-    InvalidRoleException: Boto3ClientError
-    InvalidSortByException: Boto3ClientError
-    InvalidSortOrderException: Boto3ClientError
-    InvalidTagException: Boto3ClientError
-    InvalidTagFilterException: Boto3ClientError
-    InvalidTagsToAddException: Boto3ClientError
-    InvalidTargetException: Boto3ClientError
-    InvalidTargetFilterNameException: Boto3ClientError
-    InvalidTargetGroupPairException: Boto3ClientError
-    InvalidTargetInstancesException: Boto3ClientError
-    InvalidTimeRangeException: Boto3ClientError
-    InvalidTrafficRoutingConfigurationException: Boto3ClientError
-    InvalidTriggerConfigException: Boto3ClientError
-    InvalidUpdateOutdatedInstancesOnlyValueException: Boto3ClientError
-    LifecycleEventAlreadyCompletedException: Boto3ClientError
-    LifecycleHookLimitExceededException: Boto3ClientError
-    MultipleIamArnsProvidedException: Boto3ClientError
-    OperationNotSupportedException: Boto3ClientError
-    ResourceArnRequiredException: Boto3ClientError
-    ResourceValidationException: Boto3ClientError
-    RevisionDoesNotExistException: Boto3ClientError
-    RevisionRequiredException: Boto3ClientError
-    RoleRequiredException: Boto3ClientError
-    TagLimitExceededException: Boto3ClientError
-    TagRequiredException: Boto3ClientError
-    TagSetListLimitExceededException: Boto3ClientError
-    ThrottlingException: Boto3ClientError
-    TriggerTargetsLimitExceededException: Boto3ClientError
-    UnsupportedActionForDeploymentTypeException: Boto3ClientError
+    AlarmsLimitExceededException: Type[Boto3ClientError]
+    ApplicationAlreadyExistsException: Type[Boto3ClientError]
+    ApplicationDoesNotExistException: Type[Boto3ClientError]
+    ApplicationLimitExceededException: Type[Boto3ClientError]
+    ApplicationNameRequiredException: Type[Boto3ClientError]
+    ArnNotSupportedException: Type[Boto3ClientError]
+    BatchLimitExceededException: Type[Boto3ClientError]
+    BucketNameFilterRequiredException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    DeploymentAlreadyCompletedException: Type[Boto3ClientError]
+    DeploymentAlreadyStartedException: Type[Boto3ClientError]
+    DeploymentConfigAlreadyExistsException: Type[Boto3ClientError]
+    DeploymentConfigDoesNotExistException: Type[Boto3ClientError]
+    DeploymentConfigInUseException: Type[Boto3ClientError]
+    DeploymentConfigLimitExceededException: Type[Boto3ClientError]
+    DeploymentConfigNameRequiredException: Type[Boto3ClientError]
+    DeploymentDoesNotExistException: Type[Boto3ClientError]
+    DeploymentGroupAlreadyExistsException: Type[Boto3ClientError]
+    DeploymentGroupDoesNotExistException: Type[Boto3ClientError]
+    DeploymentGroupLimitExceededException: Type[Boto3ClientError]
+    DeploymentGroupNameRequiredException: Type[Boto3ClientError]
+    DeploymentIdRequiredException: Type[Boto3ClientError]
+    DeploymentIsNotInReadyStateException: Type[Boto3ClientError]
+    DeploymentLimitExceededException: Type[Boto3ClientError]
+    DeploymentNotStartedException: Type[Boto3ClientError]
+    DeploymentTargetDoesNotExistException: Type[Boto3ClientError]
+    DeploymentTargetIdRequiredException: Type[Boto3ClientError]
+    DeploymentTargetListSizeExceededException: Type[Boto3ClientError]
+    DescriptionTooLongException: Type[Boto3ClientError]
+    ECSServiceMappingLimitExceededException: Type[Boto3ClientError]
+    GitHubAccountTokenDoesNotExistException: Type[Boto3ClientError]
+    GitHubAccountTokenNameRequiredException: Type[Boto3ClientError]
+    IamArnRequiredException: Type[Boto3ClientError]
+    IamSessionArnAlreadyRegisteredException: Type[Boto3ClientError]
+    IamUserArnAlreadyRegisteredException: Type[Boto3ClientError]
+    IamUserArnRequiredException: Type[Boto3ClientError]
+    InstanceDoesNotExistException: Type[Boto3ClientError]
+    InstanceIdRequiredException: Type[Boto3ClientError]
+    InstanceLimitExceededException: Type[Boto3ClientError]
+    InstanceNameAlreadyRegisteredException: Type[Boto3ClientError]
+    InstanceNameRequiredException: Type[Boto3ClientError]
+    InstanceNotRegisteredException: Type[Boto3ClientError]
+    InvalidAlarmConfigException: Type[Boto3ClientError]
+    InvalidApplicationNameException: Type[Boto3ClientError]
+    InvalidArnException: Type[Boto3ClientError]
+    InvalidAutoRollbackConfigException: Type[Boto3ClientError]
+    InvalidAutoScalingGroupException: Type[Boto3ClientError]
+    InvalidBlueGreenDeploymentConfigurationException: Type[Boto3ClientError]
+    InvalidBucketNameFilterException: Type[Boto3ClientError]
+    InvalidComputePlatformException: Type[Boto3ClientError]
+    InvalidDeployedStateFilterException: Type[Boto3ClientError]
+    InvalidDeploymentConfigIdException: Type[Boto3ClientError]
+    InvalidDeploymentConfigNameException: Type[Boto3ClientError]
+    InvalidDeploymentGroupNameException: Type[Boto3ClientError]
+    InvalidDeploymentIdException: Type[Boto3ClientError]
+    InvalidDeploymentInstanceTypeException: Type[Boto3ClientError]
+    InvalidDeploymentStatusException: Type[Boto3ClientError]
+    InvalidDeploymentStyleException: Type[Boto3ClientError]
+    InvalidDeploymentTargetIdException: Type[Boto3ClientError]
+    InvalidDeploymentWaitTypeException: Type[Boto3ClientError]
+    InvalidEC2TagCombinationException: Type[Boto3ClientError]
+    InvalidEC2TagException: Type[Boto3ClientError]
+    InvalidECSServiceException: Type[Boto3ClientError]
+    InvalidFileExistsBehaviorException: Type[Boto3ClientError]
+    InvalidGitHubAccountTokenException: Type[Boto3ClientError]
+    InvalidGitHubAccountTokenNameException: Type[Boto3ClientError]
+    InvalidIamSessionArnException: Type[Boto3ClientError]
+    InvalidIamUserArnException: Type[Boto3ClientError]
+    InvalidIgnoreApplicationStopFailuresValueException: Type[Boto3ClientError]
+    InvalidInputException: Type[Boto3ClientError]
+    InvalidInstanceIdException: Type[Boto3ClientError]
+    InvalidInstanceNameException: Type[Boto3ClientError]
+    InvalidInstanceStatusException: Type[Boto3ClientError]
+    InvalidInstanceTypeException: Type[Boto3ClientError]
+    InvalidKeyPrefixFilterException: Type[Boto3ClientError]
+    InvalidLifecycleEventHookExecutionIdException: Type[Boto3ClientError]
+    InvalidLifecycleEventHookExecutionStatusException: Type[Boto3ClientError]
+    InvalidLoadBalancerInfoException: Type[Boto3ClientError]
+    InvalidMinimumHealthyHostValueException: Type[Boto3ClientError]
+    InvalidNextTokenException: Type[Boto3ClientError]
+    InvalidOnPremisesTagCombinationException: Type[Boto3ClientError]
+    InvalidOperationException: Type[Boto3ClientError]
+    InvalidRegistrationStatusException: Type[Boto3ClientError]
+    InvalidRevisionException: Type[Boto3ClientError]
+    InvalidRoleException: Type[Boto3ClientError]
+    InvalidSortByException: Type[Boto3ClientError]
+    InvalidSortOrderException: Type[Boto3ClientError]
+    InvalidTagException: Type[Boto3ClientError]
+    InvalidTagFilterException: Type[Boto3ClientError]
+    InvalidTagsToAddException: Type[Boto3ClientError]
+    InvalidTargetException: Type[Boto3ClientError]
+    InvalidTargetFilterNameException: Type[Boto3ClientError]
+    InvalidTargetGroupPairException: Type[Boto3ClientError]
+    InvalidTargetInstancesException: Type[Boto3ClientError]
+    InvalidTimeRangeException: Type[Boto3ClientError]
+    InvalidTrafficRoutingConfigurationException: Type[Boto3ClientError]
+    InvalidTriggerConfigException: Type[Boto3ClientError]
+    InvalidUpdateOutdatedInstancesOnlyValueException: Type[Boto3ClientError]
+    LifecycleEventAlreadyCompletedException: Type[Boto3ClientError]
+    LifecycleHookLimitExceededException: Type[Boto3ClientError]
+    MultipleIamArnsProvidedException: Type[Boto3ClientError]
+    OperationNotSupportedException: Type[Boto3ClientError]
+    ResourceArnRequiredException: Type[Boto3ClientError]
+    ResourceValidationException: Type[Boto3ClientError]
+    RevisionDoesNotExistException: Type[Boto3ClientError]
+    RevisionRequiredException: Type[Boto3ClientError]
+    RoleRequiredException: Type[Boto3ClientError]
+    TagLimitExceededException: Type[Boto3ClientError]
+    TagRequiredException: Type[Boto3ClientError]
+    TagSetListLimitExceededException: Type[Boto3ClientError]
+    ThrottlingException: Type[Boto3ClientError]
+    TriggerTargetsLimitExceededException: Type[Boto3ClientError]
+    UnsupportedActionForDeploymentTypeException: Type[Boto3ClientError]
 
 
 class CodeDeployClient:
